==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Modify/Rotate/ts/Rotate_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+68"/>
        <source>Center point</source>
        <translatorcomment>--google--
Salta aos pontos de centro
Fazer espiral com bitmap(s) seleccionado(s) em redor de um ponto central</translatorcomment>
        <translation>Ponto central</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translatorcomment>--exact match--
--file: IsoProject_pt.ts--
Indique o ponto de referência
Copie entidade com ponto de referência  para o clipboard</translatorcomment>
        <translation>Ponto de referência</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translatorcomment>--exact match--
--file: IsoProject_pt.ts--
Indique o ponto de destino
Ponto de destino</translatorcomment>
        <translation>Ponto de destino</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Rotacione
&amp;Girado (linear)</translatorcomment>
        <translation>&amp;Rotacione</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Opções Mova e Rotacione
Opções de Rotacione</translatorcomment>
        <translation>Opções de rotacione</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: Mirror_pt.ts--
Número de cópias
Entre o número de cópias</translatorcomment>
        <translation>Número de cópias</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: Mirror_pt.ts--
&amp;Apague o Original
&amp;Apague o original</translatorcomment>
        <translation>&amp;Apague o original</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: Mirror_pt.ts--
&amp;Mantenha o Original
&amp;Mantenha o original</translatorcomment>
        <translation>&amp;Mantenha o original</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Cópias &amp;Múltiplas</translatorcomment>
        <translation>Cópias &amp;múltiplas</translation>
    </message>
    <message>
        <location line="+110"/>
        <source>&amp;Angle (a):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Ângulo (a):</translatorcomment>
        <translation>Â&amp;ngulo (a):</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--exact match--
--file: Mirror_pt.ts--
Use camada e &amp;atributos atual</translatorcomment>
        <translation>Use camada e &amp;atributos atual</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Modify/Rotate/ts/Rotate_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translatorcomment>--google--
Salta aos pontos de centro
Fazer espiral com bitmap(s) seleccionado(s) em redor de um ponto central</translatorcomment>
        <translation>Ponto central</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translatorcomment>--exact match--
--file: IsoProject_pt.ts--
Indique o ponto de referência
Copie entidade com ponto de referência  para o clipboard</translatorcomment>
        <translation>Ponto de referência</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translatorcomment>--exact match--
--file: IsoProject_pt.ts--
Indique o ponto de destino
Ponto de destino</translatorcomment>
        <translation>Ponto de destino</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Rotacione
&amp;Girado (linear)</translatorcomment>
        <translation>&amp;Rotacione</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Opções Mova e Rotacione
Opções de Rotacione</translatorcomment>
        <translation>Opções de Rotação</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: Mirror_pt.ts--
Número de cópias
Entre o número de cópias</translatorcomment>
        <translation>Número de Cópias</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: Mirror_pt.ts--
&amp;Apague o Original
&amp;Apague o original</translatorcomment>
        <translation>&amp;Elimine o original</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: Mirror_pt.ts--
&amp;Mantenha o Original
&amp;Mantenha o original</translatorcomment>
        <translation>&amp;Mantenha o original</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Cópias &amp;Múltiplas</translatorcomment>
        <translation>Cópias &amp;múltiplas</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Ângulo (a):</translatorcomment>
        <translation>Â&amp;ngulo (a):</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--exact match--
--file: Mirror_pt.ts--
Use camada e &amp;atributos atual</translatorcomment>
        <translation>Use a camada e os &amp;atributos atuais</translation>
    </message>
</context>
</TS>
